pub struct CollectingSink { /* private fields */ }Expand description
A sink that collects all emitted events into a Vec. Useful in integration
tests that need to assert on the sequence of events.
Implementations
Sourceimpl CollectingSink
impl CollectingSink
pub fn new() -> Self
Sourcepub fn drain(&self) -> Vec<ProofEvent>
pub fn drain(&self) -> Vec<ProofEvent>
Drain and return all collected events.
Sourcepub fn snapshot(&self) -> Vec<ProofEvent>
pub fn snapshot(&self) -> Vec<ProofEvent>
Return a snapshot of collected events (clone).